==> sentry-9.1.0-py27-none-any.whl: sentry/static/sentry/app/components/eventsTable/eventsTableRow.jsx <==
import PropTypes from 'prop-types';
import React from 'react';
import {Link} from 'react-router';

import SentryTypes from 'app/sentryTypes';
import Avatar from 'app/components/avatar';
import DateTime from 'app/components/dateTime';
import DeviceName from 'app/components/deviceName';
import FileSize from 'app/components/fileSize';
import withOrganization from 'app/utils/withOrganization';

class EventsTableRow extends React.Component {
  static propTypes = {
    organization: SentryTypes.Organization.isRequired,
    hasUser: PropTypes.bool,
    orgId: PropTypes.string.isRequired,
    groupId: PropTypes.string.isRequired,
    projectId: PropTypes.string,
    event: SentryTypes.Event.isRequired,
    tagList: PropTypes.arrayOf(SentryTypes.Tag),
  };

  getEventTitle = event => {
    // XXX(mitsuhiko): event.title did not exist originally.  At one point
    // all events will have this and most of this logic could go
    switch (event.type) {
      case 'error':
        if (event.metadata.type && event.metadata.value) {
          return `${event.metadata.type}: ${event.metadata.value}`;
        }
        return event.metadata.type || event.metadata.value || event.metadata.title;
      case 'csp':
        return event.metadata.message;
      case 'default':
        return event.metadata.title;
      default:
        return event.title || event.message.split('\n')[0];
    }
  };

  renderCrashFileLink() {
    const {orgId, event, projectId} = this.props;
    if (!event.crashFile) {
      return null;
    }
    const url = `/api/0/projects/${orgId}/${projectId}/events/${event.id}/attachments/${event
      .crashFile.id}/?download=1`;
    const crashFileType =
      event.crashFile.type === 'event.minidump' ? 'Minidump' : 'Crash file';
    return (
      <small>
        {crashFileType}: <a href={url}>{event.crashFile.name}</a> (<FileSize bytes={event.crashFile.size} />)
      </small>
    );
  }

  render() {
    const {
      organization,
      className,
      event,
      orgId,
      projectId,
      groupId,
      tagList,
      hasUser,
    } = this.props;
    const tagMap = {};
    event.tags.forEach(tag => {
      tagMap[tag.key] = tag.value;
    });

    const basePath = new Set(organization.features).has('sentry10')
      ? `/organizations/${orgId}/issues/`
      : `/${orgId}/${projectId}/issues/`;

    return (
      <tr key={event.id} className={className}>
        <td>
          <h5>
            <Link to={`${basePath}${groupId}/events/${event.id}/`}>
              <DateTime date={event.dateCreated} />
            </Link>
            <small>{(this.getEventTitle(event) || '').substr(0, 100)}</small>
            {this.renderCrashFileLink()}
          </h5>
        </td>

        {hasUser && (
          <td className="event-user table-user-info">
            {event.user ? (
              <div>
                <Avatar user={event.user} size={24} className="avatar" gravatar={false} />
                {event.user.email}
              </div>
            ) : (
              <span>—</span>
            )}
          </td>
        )}

        {tagList.map(tag => {
          return (
            <td key={tag.key}>
              <div>
                {tag.key === 'device' ? (
                  <DeviceName>{tagMap[tag.key]}</DeviceName>
                ) : (
                  tagMap[tag.key]
                )}
              </div>
            </td>
          );
        })}
      </tr>
    );
  }
}

export {EventsTableRow};
export default withOrganization(EventsTableRow);

==> sentry-10.0.1-py27-none-any.whl: sentry/static/sentry/app/components/eventsTable/eventsTableRow.jsx <==
import PropTypes from 'prop-types';
import React from 'react';

import AttachmentUrl from 'app/utils/attachmentUrl';
import UserAvatar from 'app/components/avatar/userAvatar';
import DateTime from 'app/components/dateTime';
import DeviceName from 'app/components/deviceName';
import FileSize from 'app/components/fileSize';
import GlobalSelectionLink from 'app/components/globalSelectionLink';
import SentryTypes from 'app/sentryTypes';
import withOrganization from 'app/utils/withOrganization';

class EventsTableRow extends React.Component {
  static propTypes = {
    hasUser: PropTypes.bool,
    orgId: PropTypes.string.isRequired,
    groupId: PropTypes.string.isRequired,
    projectId: PropTypes.string,
    event: SentryTypes.Event.isRequired,
    tagList: PropTypes.arrayOf(SentryTypes.Tag),
  };

  renderCrashFileLink() {
    const {event, projectId} = this.props;
    if (!event.crashFile) {
      return null;
    }

    const crashFileType =
      event.crashFile.type === 'event.minidump' ? 'Minidump' : 'Crash file';

    return (
      <AttachmentUrl
        projectId={projectId}
        eventId={event.id}
        attachment={event.crashFile}
      >
        {url =>
          url && (
            <small>
              {crashFileType}: <a href={`${url}?download=1`}>{event.crashFile.name}</a> (
              <FileSize bytes={event.crashFile.size} />)
            </small>
          )
        }
      </AttachmentUrl>
    );
  }

  render() {
    const {className, event, orgId, groupId, tagList, hasUser} = this.props;
    const tagMap = {};
    event.tags.forEach(tag => {
      tagMap[tag.key] = tag.value;
    });
    const link = `/organizations/${orgId}/issues/${groupId}/events/${event.id}/`;

    return (
      <tr key={event.id} className={className}>
        <td>
          <h5>
            <GlobalSelectionLink to={link}>
              <DateTime date={event.dateCreated} />
            </GlobalSelectionLink>
            <small>{event.title.substr(0, 100)}</small>
            {this.renderCrashFileLink()}
          </h5>
        </td>

        {hasUser && (
          <td className="event-user table-user-info">
            {event.user ? (
              <div>
                <UserAvatar
                  user={event.user}
                  size={24}
                  className="avatar"
                  gravatar={false}
                />
                {event.user.email}
              </div>
            ) : (
              <span>—</span>
            )}
          </td>
        )}

        {tagList.map(tag => {
          return (
            <td key={tag.key}>
              <div>
                {tag.key === 'device' ? (
                  <DeviceName>{tagMap[tag.key]}</DeviceName>
                ) : (
                  tagMap[tag.key]
                )}
              </div>
            </td>
          );
        })}
      </tr>
    );
  }
}

export {EventsTableRow};
export default withOrganization(EventsTableRow);
